

### <a name="manual"></a> Newpage block

Add newpage to document flow.

| Key       |      Description      | Default |
|:----------|:--------------------- |:---------|
| type      |  newpage              |
| onPrevious|  (optional) force the page layout to change just after the previous flowable has been rendered         | False |

Example:
```YAML
- type    : newpage
```

Back to [Documentation](../../../README.md#block_basic)
